# pypwsqc

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14177798.svg)](https://doi.org/10.5281/zenodo.14177798)

`pypwsqc` is a Python package for quality control (QC) of data from personal
weather stations (PWS), developed within the COST Action OPENSENSE.

It's current main goal is to provide a unified implementation of the QC methods
from [PWSQC](https://github.com/LottedeVos/PWSQC) (written in R, but parts of it
are available in Python) and
[pws-pyqc](https://github.com/AbbasElHachem/pws-pyqc) (written in Python).

<!-- SPHINX-START -->

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/OpenSenseAction/pypwsqc/workflows/CI/badge.svg
[actions-link]:             https://github.com/OpenSenseAction/pypwsqc/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/pypwsqc
[conda-link]:               https://github.com/conda-forge/pypwsqc-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/OpenSenseAction/pypwsqc/discussions
[pypi-link]:                https://pypi.org/project/pypwsqc/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/pypwsqc
[pypi-version]:             https://img.shields.io/pypi/v/pypwsqc
[rtd-badge]:                https://readthedocs.org/projects/pypwsqc/badge/?version=latest
[rtd-link]:                 https://pypwsqc.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->
